@@ -25,6 +25,7 @@ GenericSection::GenericSection(ConnectionSettings::Ptr connSettings, QFrame *par
     initUI();
     m_connIdItem->textEdit()->installEventFilter(this);
     connect(m_autoConnItem, &SwitchWidget::checkedChanged, this, &GenericSection::editClicked);
+    connect(m_connIdItem->textEdit(), &QLineEdit::textChanged, this,  &GenericSection::ssidChanged);
 }
 
 GenericSection::~GenericSection()
@@ -104,7 +105,12 @@ void GenericSection::setConnectionNameEditable(const bool editable)
 void GenericSection::initUI()
 {
     setAccessibleName("GenericSection");
-    m_connIdItem->setTitle(tr("Name"));
+    if (m_connSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
+        m_connIdItem->setTitle(tr("Name (SSID)"));
+    } else {
+        m_connIdItem->setTitle(tr("Name"));
+    }
+
     m_connIdItem->setText(m_connSettings->id());
     m_connIdItem->setPlaceholderText(tr("Required"));
     m_autoConnItem->setChecked(m_connSettings->autoconnect());
@@ -117,8 +123,10 @@ void GenericSection::initUI()
 bool GenericSection::eventFilter(QObject *watched, QEvent *event)
 {
     // 实现鼠标点击编辑框，确定按钮激活，统一网络模块处理，捕捉FocusIn消息
-    if (event->type() == QEvent::FocusIn && dynamic_cast<QLineEdit *>(watched))
+    QLineEdit * lineEdit = qobject_cast<QLineEdit *>(watched);
+    if (lineEdit && event->type() == QEvent::FocusIn && lineEdit->isEnabled()) {
         Q_EMIT editClicked();
+    }
 
     return QWidget::eventFilter(watched, event);
 }
