@@ -1,4 +1,15 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Беспроводная сеть</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Проводная сеть</translation>
+    </message>
+</context>
 <context>
     <name>NetworkPlugin</name>
     <message>
@@ -6,6 +17,31 @@
         <translation>Сеть</translation>
     </message>
 </context>
+<context>
+    <name>WirelessItem</name>
+    <message>
+        <source>Connect to hidden network</source>
+        <translation>Подключиться к скрытой сети</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Пароль</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Отмена</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Подключить</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Имя (SSID)</translation>
+    </message>
+</context>
 <context>
     <name>dde::network::NetworkDetails</name>
     <message>
@@ -24,14 +60,14 @@
         <source>Security Type</source>
         <translation>Тип безопасности</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Диапазон</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Канал</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Диапазон</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Интерфейс</translation>
